@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2023 the original author or authors.
+ * Copyright 2001-2024 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,6 +19,7 @@ import org.easymock.internal.*;
 import org.easymock.internal.matchers.*;
 
 import java.util.Comparator;
+import java.util.function.UnaryOperator;
 
 /**
  * Main EasyMock class. Contains methods to create, replay and verify mocks and
@@ -1841,6 +1842,37 @@ public class EasyMock {
         return Capture.newInstance(type);
     }
 
+    /**
+     * Create a new capture instance with a specific {@link org.easymock.CaptureType}
+     * and a specific transformation function to change the values into a different value.
+     * <p>
+     * One useful usage for the transformation is when the captured argument will be mutated
+     * after the capture, and you would like to save it before mutation.
+     *
+     * @param type capture type wanted
+     * @param transform the transform function
+     * @param <T> type of the class to be captured
+     * @return the new capture object
+     */
+    public static <T> Capture<T> newCapture(CaptureType type, UnaryOperator<T> transform) {
+        return Capture.newInstance(type, transform);
+    }
+
+    /**
+     * Create a new capture instance with a specific and a specific transformation
+     * function to change the values into a different value.
+     * <p>
+     * One useful usage for the transformation is when the captured argument will be mutated
+     * after the capture, and you would like to save it before mutation.
+     *
+     * @param transform the transform function
+     * @param <T> type of the class to be captured
+     * @return the new capture object
+     */
+    public static <T> Capture<T> newCapture(UnaryOperator<T> transform) {
+        return Capture.newInstance(transform);
+    }
+
     /**
      * Expect any object but captures it for later use.
      *
