@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2023 the original author or authors.
+ * Copyright 2001-2024 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -27,7 +27,7 @@ import java.util.Set;
 /**
  * Class containing the data required for a class mock to work.
  */
-public class ClassMockingData implements Serializable {
+public final class ClassMockingData implements Serializable {
 
     private static final long serialVersionUID = -1L;
 
