@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2023 the original author or authors.
+ * Copyright 2001-2024 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -31,7 +31,7 @@ import static java.lang.Character.*;
  *
  * @author OFFIS, Tammo Freese
  */
-public class Invocation implements Serializable {
+public final class Invocation implements Serializable {
 
     private static final long serialVersionUID = 1604995470419943411L;
 
@@ -165,14 +165,11 @@ public class Invocation implements Serializable {
             return methodName;
         }
         String mockName = mock.toString();
-        // Cheap trick to check if the name is the default "EasyMock for ..." or a name
-        // provided when creating the mock
-        if (isJavaIdentifier(mockName)) {
-            return mockName + "." + methodName;
+        if (!isDefaultName(mockName)) {
+            mockName = "Mock named " + mockName;
         }
-
         Class<?> clazz = MocksControl.getMockedClass(mock);
-        return clazz.getSimpleName() + "." + methodName;
+        return mockName + " -> " + clazz.getSimpleName() + "." + methodName;
     }
 
     public void addCapture(Captures<Object> capture, Object value) {
@@ -204,17 +201,8 @@ public class Invocation implements Serializable {
         }
     }
 
-    public static boolean isJavaIdentifier(String mockName) {
-        if (mockName.length() == 0 || mockName.indexOf(' ') > -1
-                || !Character.isJavaIdentifierStart(mockName.charAt(0))) {
-            return false;
-        }
-        for (char c : mockName.substring(1).toCharArray()) {
-            if (!isJavaIdentifierPart(c)) {
-                return false;
-            }
-        }
-        return true;
+    private static boolean isDefaultName(String mockName) {
+        return mockName.startsWith("EasyMock for");
     }
 
     private void readObject(java.io.ObjectInputStream stream) throws IOException,
