@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2023 the original author or authors.
+ * Copyright 2001-2024 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@ import java.io.Serializable;
  *
  * @author OFFIS, Tammo Freese
  */
-public class Range implements Serializable {
+public final class Range implements Serializable {
 
     private static final long serialVersionUID = -6743402320315331536L;
 
