@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2023 the original author or authors.
+ * Copyright 2001-2024 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,7 +23,14 @@ import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
+import java.io.ByteArrayInputStream;
+import java.io.ByteArrayOutputStream;
+import java.io.IOException;
+import java.io.ObjectInputStream;
+import java.io.ObjectOutputStream;
+import java.io.Serializable;
 import java.util.Arrays;
+import java.util.function.UnaryOperator;
 
 import org.easymock.Capture;
 import org.easymock.CaptureType;
@@ -371,4 +378,73 @@ public class CaptureTest {
 
         assertEquals(0L, capture.getValue());
     }
+
+    private <T> Capture<Integer> testCaptureTypeAndTransform(CaptureType type) {
+        IMethods mock = createMock(IMethods.class);
+        Capture<Integer> captured = Capture.newInstance(type, t -> t * 100);
+
+        expect(mock.oneArg(captureInt(captured))).andReturn("1");
+        expect(mock.oneArg(anyInt())).andReturn("1");
+        expect(mock.oneArg(captureInt(captured))).andReturn("2").times(2);
+        mock.twoArgumentMethod(captureInt(captured), eq(6));
+        mock.twoArgumentMethod(captureInt(captured), captureInt(captured));
+
+        replay(mock);
+
+        mock.oneArg(1);
+        mock.oneArg(2);
+        mock.oneArg(3);
+        mock.oneArg(4);
+        mock.twoArgumentMethod(5, 6);
+        mock.twoArgumentMethod(7, 8);
+
+        verify(mock);
+
+        return captured;
+    }
+
+    @Test
+    public void testTransformFirst() {
+        Capture<Integer> captured = testCaptureTypeAndTransform(CaptureType.FIRST);
+        assertEquals(100, (int) captured.getValue());
+    }
+
+    @Test
+    public void testTransformLast() {
+        Capture<Integer> captured = testCaptureTypeAndTransform(CaptureType.LAST);
+        assertEquals(800, (int) captured.getValue());
+    }
+
+    @Test
+    public void testTransformAll() {
+        Capture<Integer> captured = testCaptureTypeAndTransform(CaptureType.ALL);
+        assertEquals(Arrays.asList(100, 300, 400, 500, 700, 800), captured.getValues());
+    }
+
+    @Test
+    public void serializableDefaultTransform() throws Exception  {
+        Capture<String> capture = Capture.newInstance();
+        assertEquals("test", serializable(capture));
+    }
+
+    @Test
+    public void serializableCustomTransform() throws Exception  {
+        Capture<String> capture = Capture.newInstance((Serializable & UnaryOperator<String>) t -> "x" + t);
+        assertEquals("xtest", serializable(capture));
+    }
+
+    private String serializable(Capture<String> capture) throws IOException, ClassNotFoundException {
+        try (ByteArrayOutputStream bOut = new ByteArrayOutputStream(); ObjectOutputStream out = new ObjectOutputStream(bOut)) {
+            out.writeObject(capture);
+            out.flush();
+            byte[] buffer = bOut.toByteArray();
+            try (ByteArrayInputStream bIn = new ByteArrayInputStream(buffer); ObjectInputStream in = new ObjectInputStream(bIn)) {
+                @SuppressWarnings("unchecked")
+                Capture<String> result = (Capture<String>) in.readObject();
+                result.setValue("test");
+                return result.getValue();
+            }
+        }
+    }
+
 }
