@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2022 the original author or authors.
+ * Copyright 2001-2024 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,11 +16,11 @@
 package org.easymock.tests2;
 
 import static org.easymock.EasyMock.*;
-import static org.junit.Assert.*;
 
 import org.easymock.tests.IMethods;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 /**
  * @author OFFIS, Tammo Freese
@@ -29,7 +29,7 @@ public class NiceMockTest {
 
     IMethods mock;
 
-    @Before
+    @BeforeEach
     public void setup() {
         mock = createNiceMock(IMethods.class);
         replay(mock);
@@ -37,25 +37,25 @@ public class NiceMockTest {
 
     @Test
     public void defaultReturnValueBoolean() {
-        assertFalse(mock.booleanReturningMethod(12));
+        Assertions.assertFalse(mock.booleanReturningMethod(12));
         verify(mock);
     }
 
     @Test
     public void defaultReturnValueFloat() {
-        assertEquals(0.0f, mock.floatReturningMethod(12), 0.0f);
+        Assertions.assertEquals(0.0f, mock.floatReturningMethod(12), 0.0f);
         verify(mock);
     }
 
     @Test
     public void defaultReturnValueDouble() {
-        assertEquals(0.0d, mock.doubleReturningMethod(12), 0.0d);
+        Assertions.assertEquals(0.0d, mock.doubleReturningMethod(12), 0.0d);
         verify(mock);
     }
 
     @Test
     public void defaultReturnValueObject() {
-        assertNull(mock.objectReturningMethod(12));
+        Assertions.assertNull(mock.objectReturningMethod(12));
         verify(mock);
     }
 }
